@@ -81,7 +81,7 @@ test_that( 'read HTML saved as XLS', {
   
   expect_equal( 
     read.any( test_file( 'html-as-xls.xls' ), header = FALSE, verbose = FALSE )$V1[1],
-    'sheet1'
+    'value1'
   )
   
 })
@@ -132,3 +132,23 @@ test_that( 'times read in properly', {
 #  }
 #  
 #})
+
+test_that( 'read xlsb', {
+
+  expect_equal( 
+    nrow(read.any( test_file( 'sample.xlsb'))),
+    14
+  )
+
+  expect_equal( 
+    nrow(read.any( test_file( 'sample.xlsb'), sheet = 1)),
+    14
+  )
+
+  expect_equal( 
+    nrow(read.any( test_file( 'sample.xlsb'), sheet = 2)),
+    14
+  )
+
+})
+
